@@ -40,7 +40,7 @@ ags_hlevel_box_get_type(void)
   static volatile gsize g_define_type_id__volatile = 0;
 
   if(g_once_init_enter (&g_define_type_id__volatile)){
-    GType ags_type_hlevel_box;
+    GType ags_type_hlevel_box = 0;
 
     static const GTypeInfo ags_hlevel_box_info = {
       sizeof (AgsHLevelBoxClass),
@@ -58,7 +58,7 @@ ags_hlevel_box_get_type(void)
 						 "AgsHLevelBox", &ags_hlevel_box_info,
 						 0);
 
-    g_once_init_leave (&g_define_type_id__volatile, ags_type_hlevel_box);
+    g_once_init_leave(&g_define_type_id__volatile, ags_type_hlevel_box);
   }
 
   return g_define_type_id__volatile;
@@ -83,7 +83,7 @@ ags_hlevel_box_init(AgsHLevelBox *hlevel_box)
  * 
  * Returns: the new #AgsHLevelBox instance
  * 
- * Since: 1.4.0
+ * Since: 2.0.0
  */
 AgsHLevelBox*
 ags_hlevel_box_new()
